/* Directives */

summitApp
    // page preloader
    .directive('pageLoader', [
        '$timeout',
        function ($timeout) {
            return {
                restrict: 'AE',
                template: '<div class="rect1"></div><div class="rect2"></div><div class="rect3"></div><div class="rect4"></div><div class="rect5"></div>',
                link: function (scope, el, attrs) {
                    el.addClass('pageLoader hide');
                    scope.$on('$stateChangeStart', function (event) {
                        el.toggleClass('hide animate');
                    });
                    scope.$on('$stateChangeSuccess', function (event, toState, toParams, fromState) {
                        event.targetScope.$watch('$viewContentLoaded', function () {
                            $timeout(function () {
                                //el.toggleClass('hide animate')
                                el.addClass('pageLoader hide');// Had to add this hack to kill the extra animation
                            }, 600);
                        })
                    });
                }
            };
        }
    ])

    // show/hide side menu
    .directive('menuToggle', [
        '$rootScope',
        '$cookieStore',
        '$window',
        function ($rootScope, $cookieStore, $window) {
            return {
                restrict: 'E',
                template: '<span class="menu_toggle" ng-click="toggleSidebar()"><span class="icon_menu_toggle" ><i class="arrow_carrot-2left" ng-class="sideNavCollapsed ? \'hide\' : \'\'"></i><i class="arrow_carrot-2right" ng-class="sideNavCollapsed ? \'\' : \'hide\'"></i></span></span>',
                link: function (scope, el, attrs) {
                    var mobileView = 992;
                    $rootScope.getWidth = function () {
                        return window.innerWidth;
                    };
                    $rootScope.$watch($rootScope.getWidth, function (newValue, oldValue) {
                        if (newValue >= mobileView) {
                            if (angular.isDefined($cookieStore.get('sideNavCollapsed'))) {
                                if ($cookieStore.get('sideNavCollapsed') == false) {
                                    $rootScope.sideNavCollapsed = false;
                                }
                                else {
                                    $rootScope.sideNavCollapsed = true;
                                }
                            }
                            else {
                                $rootScope.sideNavCollapsed = false;
                            }
                        }
                        else {
                            $rootScope.sideNavCollapsed = true;
                        }
                    });
                    scope.toggleSidebar = function () {
                        $rootScope.sideNavCollapsed = !$rootScope.sideNavCollapsed;
                        $cookieStore.put('sideNavCollapsed', $rootScope.sideNavCollapsed);
                    };
                    window.onresize = function () {
                        $rootScope.$apply();
                    };

                }
            };
        }
    ])

    .directive('focusOnInput', function ($timeout) {
        return {
            link: function (scope, element, attrs) {
                scope.$watch(attrs.focusOnInput, function (value) {
                    if (value === true) {
                        //console.log('Setting Default Focus for Input on Modal');
                        $timeout(function () {
                            element[0].focus();
                            element[0].select();
                            scope[attrs.focusMe] = false;
                        });                    
                    }
                });
            }
        };
    })

// update datatables fixedHeader position
.directive('updateFixedHeaders', function ($window) {
        return function (scope, element) {
            var w = angular.element($window);
            scope.getElDimensions = function () {
                return {
                    'w': element.width(),
                    'h': element.height()
                };
            };
            scope.$watch(scope.getElDimensions, function (newValue, oldValue) {
                if (typeof oFH != 'undefined') {
                    oFH._fnUpdateClones(true);
                    oFH._fnUpdatePositions();
                }
            }, true);
            w.bind('resize', function () {
                scope.$apply();
            });
        };
    })

// ng-repeat after render callback
.directive('onLastRepeat', function ($timeout) {
        return function (scope, element, attrs) {
            if (scope.$last) {
                $timeout(function () {
                    scope.$emit('onRepeatLast', element, attrs);
                })
            }
        };
    })

// add width/height properities to Image
.directive('addImageProp', function () {
        return {
            restrict: 'A',
            link: function (scope, elem, attr) {
                elem.on('load', function () {
                    var w = !scope.isHighDensity() ? $(this).width() : $(this).width() / 2,
                        h = !scope.isHighDensity() ? $(this).height() : $(this).height() / 2;
                    $(this).attr('width', w).attr('height', h);
                });
            }
        };
    })

// dynamically adjust Digital Inputs display
.directive('footableDigitalInputs', function () {
        return function (scope, element) {
            var footableTable = element.parents('table');// Get the parent of this element
            
            // If this isn't the $last ng-repeat, then ignore
            if (!scope.$last) {
                return false;
            }
            
            
            // This is the $last ng-repeat, wait and then initialize the footable table
            scope.$evalAsync(function () {
                console.log("Initializing footableDigitalInputs");
                if (!footableTable.hasClass('footable-loaded')) {
                    footableTable.footable({
                        toggleSelector: " > tbody > tr > td > span.footable-toggle"
                    })
                }
                
                console.log("footableDigitalInputs directive: length of scope.DigitalInputs=" + scope.DigitalInputs.length);
                for (i = 0, enabled = 0; i < scope.DigitalInputs.length; i++) {
                    if (scope.DigitalInputs[i].Enabled === "TRUE") {
                        if (scope.DigitalInputs[i].Value == "1") {
                            $('#IdDigitalInput' + i + 'Value').html("ON");
                            $('#IdDigitalInput' + i + 'Value').css('color', 'white');
                            $('#IdDigitalInput' + i + 'Value').css('background-color', 'green');
                            $('#IdDigitalInput' + i + 'Value').css('border-color', 'green');
                        }
                        else {
                            $('#IdDigitalInput' + i + 'Value').html("OFF");
                            $('#IdDigitalInput' + i + 'Value').css('color', 'white');
                            $('#IdDigitalInput' + i + 'Value').css('background-color', 'red');
                            $('#IdDigitalInput' + i + 'Value').css('border-color', 'red');
                        }
                    }
                    else {
                        $('#IdDigitalInput' + i + 'Value').html("--");
                        $('#IdDigitalInput' + i + 'Value').css('color', 'white');
                        $('#IdDigitalInput' + i + 'Value').css('background-color', 'grey');
                        $('#IdDigitalInput' + i + 'Value').css('border-color', 'grey');
                    }
                }
                
                footableTable.trigger('footable_initialized');
                footableTable.trigger('footable_resize');
                footableTable.data('footable').redraw();

            });
        };
    })

// dynamically adjust Digital Outputs display
.directive('footableDigitalOutputs', function () {
        return function (scope, element) {
            var footableTable = element.parents('table');// Get the parent of this element
            
            // If this isn't the $last ng-repeat, then ignore
            if (!scope.$last) {
                return false;
            }
            
            
            // This is the $last ng-repeat, wait and then initialize the footable table
            scope.$evalAsync(function () {
                console.log("Initializing footableDigitalOutputs");
                if (!footableTable.hasClass('footable-loaded')) {
                    footableTable.footable({
                        toggleSelector: " > tbody > tr > td > span.footable-toggle"
                    })
                }
                
                console.log("footableDigitalOutputs directive: length of scope.DigitalOutputs=" + scope.DigitalOutputs.length);
                for (i = 0, enabled = 0; i < scope.DigitalOutputs.length; i++) {
                    if (scope.DigitalOutputs[i].Enabled === "TRUE") {
                        if (scope.DigitalOutputs[i].Value == "1") {
                            $('#IdDigitalOutput' + i + 'Value').html("ON");
                            $('#IdDigitalOutput' + i + 'Value').css('color', 'white');
                            $('#IdDigitalOutput' + i + 'Value').css('background-color', 'green');
                            $('#IdDigitalOutput' + i + 'Value').css('border-color', 'green');
                            $('#IdDigitalOutput' + i + 'Set').html("Turn OFF");
                        } else {
                            $('#IdDigitalOutput' + i + 'Value').html("OFF");
                            $('#IdDigitalOutput' + i + 'Value').css('color', 'white');
                            $('#IdDigitalOutput' + i + 'Value').css('background-color', 'red');
                            $('#IdDigitalOutput' + i + 'Value').css('border-color', 'red');
                            $('#IdDigitalOutput' + i + 'Set').html("Turn ON");
                        }
                        // Hard-coded switch back to Primary from grey or unknown
                        $('#IdDigitalOutput' + i + 'Set').css("color", " #fff");
                        $('#IdDigitalOutput' + i + 'Set').css("background-color", '#f0ad4e');
                        $('#IdDigitalOutput' + i + 'Set').css("border-color", '#f0ad4e');
                    }
                    else {
                        $('#IdDigitalOutput' + i + 'Value').html("--");
                        $('#IdDigitalOutput' + i + 'Value').css('color', 'white');
                        $('#IdDigitalOutput' + i + 'Value').css('background-color', 'grey');
                        $('#IdDigitalOutput' + i + 'Value').css('border-color', 'grey');
                        $('#IdDigitalOutput' + i + 'Set').html("--");
                        $('#IdDigitalOutput' + i + 'Set').css("color", "white");
                        $('#IdDigitalOutput' + i + 'Set').css("background-color", 'grey');
                        $('#IdDigitalOutput' + i + 'Set').css("border-color", 'grey');
                    }
                }
                
                footableTable.trigger('footable_initialized');
                footableTable.trigger('footable_resize');
                footableTable.data('footable').redraw();

            });
        };
    })

// dynamically adjust Analog Inputs display
.directive('footableAnalogInputs', function () {
        return function (scope, element) {
            var footableTable = element.parents('table');// Get the parent of this element
            
            // If this isn't the $last ng-repeat, then ignore
            if (!scope.$last) {
                return false;
            }
            
            
            // This is the $last ng-repeat, wait and then initialize the footable table
            scope.$evalAsync(function () {
                console.log("Initializing footableAnalogInputs");
                if (!footableTable.hasClass('footable-loaded')) {
                    footableTable.footable({
                        toggleSelector: " > tbody > tr > td > span.footable-toggle"
                    })
                }
                
                console.log("footableAnalogInputs directive: length of scope.AnalogInputs=" + scope.AnalogInputs.length);
                for (var i = 0, enabled = 0; i < scope.AnalogInputs.length; i++) {
                    if (scope.AnalogInputs[i].Enabled === "TRUE") {
                        
                        if (scope.AnalogInputs[i].QualifierValue == 1) {
                            $('#IdAnalogInput' + i + 'Qualifier').css('color', 'white');
                            $('#IdAnalogInput' + i + 'Qualifier').css('background-color', 'green');
                            $('#IdAnalogInput' + i + 'Qualifier').css('border-color', 'green');
                        } else {
                            $('#IdAnalogInput' + i + 'Qualifier').css('color', 'black');
                            $('#IdAnalogInput' + i + 'Qualifier').css('background-color', 'lightgrey');
                            $('#IdAnalogInput' + i + 'Qualifier').css('border-color', 'lightgrey');
                        } 
                        
                        // Show the value as green (in range) or red (out of range)
                        $('#IdAnalogInput' + i + 'Value').css('color', 'white');
                        if (scope.AnalogInputs[i].ThresholdState === 0) {
                            $('#IdAnalogInput' + i + 'Value').css('background-color', 'green');
                            $('#IdAnalogInput' + i + 'Value').css('border-color', 'green');
                        } else if (scope.AnalogInputs[i].ThresholdState != -1) {
                            $('#IdAnalogInput' + i + 'Value').css('background-color', 'red');
                            $('#IdAnalogInput' + i + 'Value').css('border-color', 'red');
                        }

                        // Show RangedValue or FormulaValues
                        var Value, LowThreshold, HighThreshold;
                        if (scope.AnalogInputs[i].FormulaId !== -1) {
                            // If we're using a formula, then change from Ranged Value to Formula Value
                            var FormulaIndex = -1;
                            for (var f = 0; f < scope.FormulasArray.length; f++) {
                                if (scope.AnalogInputs[i].FormulaId === scope.FormulasArray[f].Id) {
                                    FormulaIndex = f;
                                    break;
                                }
                            }
                            
                            // Show formula name
                            console.log('AnalogInputs directive: Formula HTML Id=' + '#IdAnalogInput' + i + 'Formula');
                            $('#IdAnalogInput' + i + 'Formula').html(scope.FormulasArray[FormulaIndex].Name);
                            
                            if (scope.AnalogInputs[i].FormulaEnabled === 1) {
                                // Show formula'd FormulaValue
                                Value = Number(scope.AnalogInputs[i].FormulaValue).toFixed(scope.FormulasArray[FormulaIndex].Decimals);
                                $('#IdAnalogInput' + i + 'Value').html(Value + " " + scope.FormulasArray[FormulaIndex].Units);
                                
                                // Show formula'd LowThreshold and HighThreshold
                                LowThreshold = Number(scope.AnalogInputs[i].FormulaLowThreshold).toFixed(scope.FormulasArray[FormulaIndex].Decimals);
                                $('#IdAnalogInput' + i + 'LowThreshold').html(LowThreshold + " " + scope.FormulasArray[FormulaIndex].Units);
                                HighThreshold = Number(scope.AnalogInputs[i].FormulaHighThreshold).toFixed(scope.FormulasArray[FormulaIndex].Decimals);
                                $('#IdAnalogInput' + i + 'HighThreshold').html(HighThreshold + " " + scope.FormulasArray[FormulaIndex].Units);
                            } else {
                                // Show formula-less RangedValue
                                $('#IdAnalogInput' + i + 'Value').html(scope.AnalogInputs[i].RangedValue + " Volts");
                                
                                // Show formula-less LowThreshold and HighThreshold
                                LowThreshold = parseFloat(scope.AnalogInputs[i].LowThreshold).toFixed(2);
                                $('#IdAnalogInput' + i + 'LowThreshold').html(LowThreshold + " Volts");
                                HighThreshold = parseFloat(scope.AnalogInputs[i].HighThreshold).toFixed(2);
                                $('#IdAnalogInput' + i + 'HighThreshold').html(HighThreshold + " Volts");
                            }
                        } else {
                            // Show formula-less RangedValue
                            $('#IdAnalogInput' + i + 'Value').html(scope.AnalogInputs[i].RangedValue + " Volts");

                            // Show formula-less LowThreshold and HighThreshold
                            LowThreshold = parseFloat(scope.AnalogInputs[i].LowThreshold).toFixed(2);
                            $('#IdAnalogInput' + i + 'LowThreshold').html(LowThreshold + " Volts");
                            HighThreshold = parseFloat(scope.AnalogInputs[i].HighThreshold).toFixed(2);
                            $('#IdAnalogInput' + i + 'HighThreshold').html(HighThreshold + " Volts");
                        }
                    }
                    else {
                        if (scope.AnalogInputs[i].FormulaId !== -1) {
                            // If we're using a formula, then change from Ranged Value to Formula Value
                            var FormulaIndex = -1;
                            for (var f = 0; f < scope.FormulasArray.length; f++) {
                                if (scope.AnalogInputs[i].FormulaId === scope.FormulasArray[f].Id) {
                                    FormulaIndex = f;
                                    break;
                                }
                            }
                            
                            // Show formula name
                            console.log('AnalogInputs directive: Formula HTML Id=' + '#IdAnalogInput' + i + 'Formula');
                            $('#IdAnalogInput' + i + 'Formula').html(scope.FormulasArray[FormulaIndex].Name);
                        } 

                        // Analog Input display
                        $('#IdAnalogInput' + i + 'Value').html("--");
                        $('#IdAnalogInput' + i + 'Value').css('color', 'white');
                        $('#IdAnalogInput' + i + 'Value').css('background-color', 'grey');
                        $('#IdAnalogInput' + i + 'Value').css('border-color', 'grey');
                        
                        // Show LowThreshold and HighThreshold
                        $('#IdAnalogInput' + i + 'LowThreshold').html("--");
                        $('#IdAnalogInput' + i + 'HighThreshold').html("--");                        
                    }
                }
                
                footableTable.trigger('footable_initialized');
                footableTable.trigger('footable_resize');
                footableTable.data('footable').redraw();

            });
        };
    })

// dynamically adjust Analog Outputs display    
.directive('footableAnalogOutputs', function () {
        return function (scope, element) {
            var footableTable = element.parents('table');// Get the parent of this element
            
            // If this isn't the $last ng-repeat, then ignore
            if (!scope.$last) {
                return false;
            }
            
            
            // This is the $last ng-repeat, wait and then initialize the footable table
            scope.$evalAsync(function () {
                console.log("Initializing footableAnalogOutInputs");
                if (!footableTable.hasClass('footable-loaded')) {
                    footableTable.footable({
                        toggleSelector: " > tbody > tr > td > span.footable-toggle"
                    })
                }
                
                console.log("footableAnalogOutputs directive: length of scope.AnalogOutputs=" + scope.AnalogOutputs.length);
                for (i = 0, enabled = 0; i < scope.AnalogOutputs.length; i++) {
                    if (scope.AnalogOutputs[i].Enabled === "TRUE") {
                        var ANALOG_OUTPUT_CONVERT_TO_RAW_SLOPE = 200;
                        var ANALOG_OUTPUT_CONVERT_TO_RAW_OFFSET = 0;
                        RangedValue = ((scope.AnalogOutputs[i].RawValue - ANALOG_OUTPUT_CONVERT_TO_RAW_OFFSET) / ANALOG_OUTPUT_CONVERT_TO_RAW_SLOPE).toFixed(2);
                        $('#IdAnalogOutput' + i + 'Value').html(RangedValue + " Volts");
                        $('#IdAnalogOutput' + i + 'Value').css('color', 'white');
                        $('#IdAnalogOutput' + i + 'Value').css('background-color', 'green');
                        $('#IdAnalogOutput' + i + 'Value').css('border-color', 'green');
                        $('#IdAnalogOutput' + i + 'Set').html("Set Value");
                        $('#IdAnalogOutput' + i + 'Set').css("color", "white");
                        $('#IdAnalogOutput' + i + 'Set').css("background-color", '#f0ad4e');
                        $('#IdAnalogOutput' + i + 'Set').css("border-color", '#f0ad4e');
                    }
                    else {
                        
                        $('#IdAnalogOutput' + i + 'Value').html("--");
                        $('#IdAnalogOutput' + i + 'Value').css('color', 'white');
                        $('#IdAnalogOutput' + i + 'Value').css('background-color', 'grey');
                        $('#IdAnalogOutput' + i + 'Value').css('border-color', 'grey');
                        $('#IdAnalogOutput' + i + 'Set').html("--");
                        $('#IdAnalogOutput' + i + 'Set').css("color", "white");
                        $('#IdAnalogOutput' + i + 'Set').css("background-color", 'grey');
                        $('#IdAnalogOutput' + i + 'Set').css("border-color", 'grey');
                    }
                }
                
                footableTable.trigger('footable_initialized');
                footableTable.trigger('footable_resize');
                footableTable.data('footable').redraw();

            });
        };
    })

// dynamically adjust Analog Inputs display
.directive('footableKenwoodRules', function () {
        return function (scope, element) {
            var footableTable = element.parents('table');// Get the parent of this element
            
            // If this isn't the $last ng-repeat, then ignore
            if (!scope.$last) {
                return false;
            }
            
            // This is the $last ng-repeat, wait and then initialize the footable table
            scope.$evalAsync(function () {
                console.log("Initializing footableKenwoodRules");
                if (!footableTable.hasClass('footable-loaded')) {
                    footableTable.footable({
                        toggleSelector: " > tbody > tr > td > span.footable-toggle"
                    })
                }
                
                console.log("footableKenwoodRules directive: length of scope.KenwoodRulesArray=" + scope.KenwoodRulesArray.length);
                for (i = 0, enabled = 0; i < scope.KenwoodRulesArray.length; i++) {
                    id = scope.KenwoodRulesArray[i].Id;
                    if (scope.KenwoodRulesArray[i].Enabled === "TRUE") {
                        $('#IdKenwoodRule' + id + 'Status').css('color', 'white');
                        if (scope.KenwoodRulesArray[i].Status == 'ALIVE') {
                            $('#IdKenwoodRule' + id + 'Status').css('background-color', 'green');
                            $('#IdKenwoodRule' + id + 'Status').css('border-color', 'green');
                        } else if (scope.KenwoodRulesArray[i].Status == 'DEAD') {
                            $('#IdKenwoodRule' + id + 'Status').css('background-color', 'red');
                            $('#IdKenwoodRule' + id + 'Status').css('border-color', 'red');
                        } else {
                            $('#IdKenwoodRule' + id + 'Status').css('background-color', 'grey');
                            $('#IdKenwoodRule' + id + 'Status').css('border-color', 'grey');
                        }
                    }
                    else {
                        $('#IdKenwoodRule' + id + 'Status').css('color', 'white');
                        $('#IdKenwoodRule' + id + 'Status').css('background-color', 'grey');
                        $('#IdKenwoodRule' + id + 'Status').css('border-color', 'grey');
                    }
                }
                
                footableTable.trigger('footable_initialized');
                footableTable.trigger('footable_resize');
                footableTable.data('footable').redraw();
            });
        };
    })
;